Launches a Shiny application to interactively browse and consult Argentina's historical census data.
Value
Launches the Shiny application (invisibly returns the result of
shiny::runApp()).
Examples
if (interactive()) {
arcenso_app()
}
Launches a Shiny application to interactively browse and consult Argentina's historical census data.
Launches the Shiny application (invisibly returns the result of
shiny::runApp()).
if (interactive()) {
arcenso_app()
}